@@ -2,14 +2,14 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
                   K=2*max(c(s,s2)), n=length(s), n2=length(s2),
                   mean.prior.visibility=7, sd.prior.visibility=3,
                   df.mean.prior.visibility=1, df.sd.prior.visibility=5,
-                  beta0.mean.prior=-3, beta1.mean.prior=0,
-                  beta0.sd.prior=10, beta1.sd.prior=10,
+                  beta_0.mean.prior=-3, beta_t.mean.prior=0, beta_u.mean.prior=0,
+                  beta_0.sd.prior=10, beta_t.sd.prior=10, beta_u.sd.prior=10,
                   mem.optimism.prior=1, df.mem.optimism.prior=5, 
                   mem.scale.prior=1, df.mem.scale.prior=3, 
-                  muproposal=0.1, 
-                  nuproposal=0.15, 
-                  beta0proposal=0.1, beta1proposal=0.001,
-                  memmuproposal=0.1, memscaleproposal=0.15,
+                  mu_proposal=0.1, 
+                  nu_proposal=0.15, 
+                  beta_0_proposal=0.1, beta_t_proposal=0.001, beta_u_proposal=0.001,
+                  memmu_proposal=0.1, memscale_proposal=0.15,
                   visibility=TRUE,
                   Np=0,
                   samplesize=10,burnin=0,interval=1,burnintheta=500,burninbeta=20,
@@ -95,8 +95,9 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               mu=as.double(mean.prior.visibility), df.mean.prior.visibility=as.double(df.mean.prior.visibility),
               sigma=as.double(sd.prior.visibility), df.sd.prior.visibility=as.double(df.sd.prior.visibility),
               lnlam=as.double(lnlam), nu=as.double(nu),
-              beta0.mean.prior=as.double(beta0.mean.prior), beta0.sd.prior=as.double(beta0.sd.prior),
-              beta1.mean.prior=as.double(beta1.mean.prior), beta1.sd.prior=as.double(beta1.sd.prior),
+              beta0.mean.prior=as.double(beta_0.mean.prior), beta0.sd.prior=as.double(beta_0.sd.prior),
+              betat.mean.prior=as.double(beta_t.mean.prior), betat.sd.prior=as.double(beta_t.sd.prior),
+              betau.mean.prior=as.double(beta_u.mean.prior), betau.sd.prior=as.double(beta_u.sd.prior),
               mem.optimism.prior=as.double(log(mem.optimism.prior)), df.mem.optimism.prior=as.double(df.mem.optimism.prior),
               mem.scale.prior=as.double(mem.scale.prior), df.mem.scale.prior=as.double(df.mem.scale.prior),
               Np=as.integer(Np),
@@ -108,10 +109,10 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               rectime2=as.double(recruit.times2),
               rc=as.integer(rc),
               maxcoupons=as.integer(max.coupons),
-              muproposal=as.double(muproposal),
-              nuproposal=as.double(nuproposal),
-              beta0proposal=as.double(beta0proposal), beta1proposal=as.double(beta1proposal),
-              memmuproposal=as.double(memmuproposal), memscaleproposal=as.double(memscaleproposal),
+              muproposal=as.double(mu_proposal),
+              nuproposal=as.double(nu_proposal),
+              beta0proposal=as.double(beta_0_proposal), betatproposal=as.double(beta_t_proposal), betauproposal=as.double(beta_u_proposal),
+              memmuproposal=as.double(memmu_proposal), memscale_proposal=as.double(memscale_proposal),
               N=as.integer(prior$N),
               maxN=as.integer(prior$maxN),
               sample=double(samplesize*dimsample),
@@ -144,8 +145,8 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               sigma=as.double(sd.prior.visibility), df.sd.prior.visibility=as.double(df.sd.prior.visibility),
               lnlam=as.double(lnlam), nu=as.double(nu),
               Np=as.integer(Np),
-              muproposal=as.double(muproposal),
-              nuproposal=as.double(nuproposal),
+              muproposal=as.double(mu_proposal),
+              nuproposal=as.double(nu_proposal),
               N=as.integer(prior$N),
               maxN=as.integer(prior$maxN),
               sample=double(samplesize*dimsample),
@@ -157,6 +158,7 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
     }else{
      if(visibility){
       cat(sprintf("Using a CMP measurement error model with K = %d.\n",K))
+      dimsample <- dimsample+1
       Cret <- .C("gcmpvis",
               pop=as.integer(c(s,rep(0,prior$maxN-n1))),
               K=as.integer(K),
@@ -167,8 +169,9 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               mu=as.double(mean.prior.visibility), df.mean.prior.visibility=as.double(df.mean.prior.visibility),
               sigma=as.double(sd.prior.visibility), df.sd.prior.visibility=as.double(df.sd.prior.visibility),
               lnlam=as.double(lnlam), nu=as.double(nu),
-              beta0.mean.prior=as.double(beta0.mean.prior), beta0.sd.prior=as.double(beta0.sd.prior),
-              beta1.mean.prior=as.double(beta1.mean.prior), beta1.sd.prior=as.double(beta1.sd.prior),
+              beta0.mean.prior=as.double(beta_0.mean.prior), beta0.sd.prior=as.double(beta_0.sd.prior),
+              betat.mean.prior=as.double(beta_t.mean.prior), betat.sd.prior=as.double(beta_t.sd.prior),
+              betau.mean.prior=as.double(beta_u.mean.prior), betau.sd.prior=as.double(beta_u.sd.prior),
               mem.optimism.prior=as.double(log(mem.optimism.prior)), df.mem.optimism.prior=as.double(df.mem.optimism.prior),
               mem.scale.prior=as.double(mem.scale.prior), df.mem.scale.prior=as.double(df.mem.scale.prior),
               Np=as.integer(Np),
@@ -176,10 +179,10 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               numrec=as.integer(num.recruits),
               rectime=as.double(recruit.times),
               maxcoupons=as.integer(max.coupons),
-              muproposal=as.double(muproposal),
-              nuproposal=as.double(nuproposal),
-              beta0proposal=as.double(beta0proposal), beta1proposal=as.double(beta1proposal),
-              memmuproposal=as.double(memmuproposal), memscaleproposal=as.double(memscaleproposal),
+              muproposal=as.double(mu_proposal),
+              nuproposal=as.double(nu_proposal),
+              beta0proposal=as.double(beta_0_proposal), betatproposal=as.double(beta_t_proposal), betauproposal=as.double(beta_u_proposal),
+              memmuproposal=as.double(memmu_proposal), memscaleproposal=as.double(memscale_proposal),
               N=as.integer(prior$N),
               maxN=as.integer(prior$maxN),
               sample=double(samplesize*dimsample),
@@ -205,8 +208,8 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
               sigma=as.double(sd.prior.visibility), df.sd.prior.visibility=as.double(df.sd.prior.visibility),
               lnlam=as.double(lnlam), nu=as.double(nu),
               Np=as.integer(Np),
-              muproposal=as.double(muproposal),
-              nuproposal=as.double(nuproposal),
+              muproposal=as.double(mu_proposal),
+              nuproposal=as.double(nu_proposal),
               N=as.integer(prior$N),
               maxN=as.integer(prior$maxN),
               sample=double(samplesize*dimsample),
@@ -220,7 +223,7 @@ poscmp<-function(s,s2=NULL,rc=rep(FALSE,length=length(s2)),maxN=NULL,
     degnames <- NULL
     if(Np>0){degnames <- c(degnames,paste("pdeg",1:Np,sep=""))}
     if(visibility){
-     colnamessample <- c("N","mu","sigma","visibility1","totalsize","beta0","beta1","mem.optimism","mem.scale")
+     colnamessample <- c("N","mu","sigma","visibility1","totalsize","beta_0","beta_t","beta_u","mem.optimism","mem.scale")
      Cret$vsample<-matrix(Cret$vsample,nrow=samplesize,ncol=n1,byrow=TRUE)
      colnames(Cret$vsample) <- 1:n1
      if(!is.null(s2)){
